@@ -11,6 +11,13 @@
 #' @param init_steps Number of steps for the k-means|| initialization mode. This is an advanced setting -- the default of 2 is almost always enough. Must be > 0. Default: 2.
 #' @param init_mode Initialization algorithm. This can be either "random" to choose random points as initial cluster centers, or "k-means||" to use a parallel variant of k-means++ (Bahmani et al., Scalable K-Means++, VLDB 2012). Default: k-means||.
 #'
+#' @examples
+#'\dontrun{
+#' sc <- spark_connect(master = "local")
+#' iris_tbl <- sdf_copy_to(sc, iris, name = "iris_tbl", overwrite = TRUE)
+#' ml_kmeans(iris_tbl, Species ~ .)
+#'}
+#'
 #' @export
 ml_kmeans <- function(
   x,
@@ -95,8 +102,6 @@ ml_kmeans.tbl_spark <- function(
     predictor %>%
       ml_fit(x)
   } else {
-    if (spark_version(spark_connection(x)) < "2.0.0")
-      stop("ml_kmeans() with formula interface requires Spark 2.0.0+")
     ml_generate_ml_model(x, predictor = predictor, formula = formula, features_col = features_col,
                          type = "clustering", constructor = new_ml_model_kmeans)
   }
@@ -128,9 +133,7 @@ new_ml_kmeans <- function(jobj) {
 
 new_ml_kmeans_model <- function(jobj) {
 
-  summary <- if (invoke(jobj, "hasSummary"))
-    new_ml_summary_kmeans_model(invoke(jobj, "summary"))
-  else NULL
+  summary <- try_null(new_ml_summary_kmeans_model(invoke(jobj, "summary")))
 
   new_ml_clustering_model(
     jobj,
@@ -173,8 +176,7 @@ new_ml_model_kmeans <- function(
     cost = cost,
     summary = summary,
     subclass = "ml_model_kmeans",
-    .features = feature_names,
-    .call = call
+    .features = feature_names
   )
 }
 
