@@ -213,7 +213,10 @@ new_ml_generalized_linear_regression <- function(jobj) {
 new_ml_generalized_linear_regression_model <- function(jobj) {
   summary <- if (invoke(jobj, "hasSummary"))
   {
-    new_ml_summary_generalized_linear_regression_model(invoke(jobj, "summary"))
+    fit_intercept <- ml_get_param_map(jobj)$fit_intercept
+    new_ml_summary_generalized_linear_regression_model(
+      invoke(jobj, "summary"), fit_intercept
+      )
   } else NA
 
   new_ml_prediction_model(
@@ -228,24 +231,28 @@ new_ml_generalized_linear_regression_model <- function(jobj) {
     subclass = "ml_generalized_linear_regression_model")
 }
 
-new_ml_summary_generalized_linear_regression_model <- function(jobj) {
+new_ml_summary_generalized_linear_regression_model <- function(jobj, fit_intercept) {
   version <- jobj %>%
     spark_connection() %>%
     spark_version()
   resid <- function(x) invoke(jobj, "residuals", x) %>%
     sdf_register()
 
+  arrange_stats <- make_stats_arranger(fit_intercept)
+
   new_ml_summary(
     jobj,
     aic = invoke(jobj, "aic"),
-    coefficient_standard_errors = try_null(invoke(jobj, "coefficientStandardErrors")),
+    coefficient_standard_errors = try_null(invoke(jobj, "coefficientStandardErrors")) %>%
+      arrange_stats(),
     degrees_of_freedom = invoke(jobj, "degreesOfFreedom"),
     deviance = invoke(jobj, "deviance"),
     dispersion = invoke(jobj, "dispersion"),
     null_deviance = invoke(jobj, "nullDeviance"),
     num_instances = if (version > "2.2.0") invoke(jobj, "numInstances") else NULL,
     num_iterations = try_null(invoke(jobj, "numIterations")),
-    p_values = try_null(invoke(jobj, "pValues")),
+    p_values = try_null(invoke(jobj, "pValues")) %>%
+      arrange_stats(),
     prediction_col = invoke(jobj, "predictionCol"),
     predictions = invoke(jobj, "predictions") %>% sdf_register(),
     rank = invoke(jobj, "rank"),
@@ -254,7 +261,8 @@ new_ml_summary_generalized_linear_regression_model <- function(jobj) {
     residuals = function(type = "deviance") (invoke(jobj, "residuals", type)
                                              %>% sdf_register()),
     solver = try_null(invoke(jobj, "solver")),
-    t_values = try_null(invoke(jobj, "tValues")),
+    t_values = try_null(invoke(jobj, "tValues")) %>%
+      arrange_stats(),
     subclass = "ml_summary_generalized_linear_regression")
 }
 
