@@ -162,9 +162,10 @@ new_ml_linear_regression <- function(jobj) {
 }
 
 new_ml_linear_regression_model <- function(jobj) {
-  summary <- if (invoke(jobj, "hasSummary"))
-    new_ml_summary_linear_regression_model(invoke(jobj, "summary"))
-  else NULL
+  summary <- if (invoke(jobj, "hasSummary")) {
+    fit_intercept <- ml_get_param_map(jobj)$fit_intercept
+    new_ml_summary_linear_regression_model(invoke(jobj, "summary"), fit_intercept)
+  } else NULL
 
   new_ml_prediction_model(
     jobj,
@@ -178,10 +179,14 @@ new_ml_linear_regression_model <- function(jobj) {
     subclass = "ml_linear_regression_model")
 }
 
-new_ml_summary_linear_regression_model <- function(jobj) {
+new_ml_summary_linear_regression_model <- function(
+  jobj, fit_intercept) {
+  arrange_stats <- make_stats_arranger(fit_intercept)
+
   new_ml_summary(
     jobj,
-    coefficient_standard_errors = try_null(invoke(jobj, "coefficientStandardErrors")),
+    coefficient_standard_errors = try_null(invoke(jobj, "coefficientStandardErrors")) %>%
+      arrange_stats(),
     degrees_of_freedom = if (spark_version(spark_connection(jobj)) >= "2.2.0")
       invoke(jobj, "degreesOfFreedom") else NULL,
     deviance_residuals = invoke(jobj, "devianceResiduals"),
@@ -191,13 +196,15 @@ new_ml_summary_linear_regression_model <- function(jobj) {
     mean_absolute_error = invoke(jobj, "meanAbsoluteError"),
     mean_squared_error = invoke(jobj, "meanSquaredError"),
     num_instances = invoke(jobj, "numInstances"),
-    p_values = try_null(invoke(jobj, "pValues")),
+    p_values = try_null(invoke(jobj, "pValues")) %>%
+      arrange_stats(),
     prediction_col = invoke(jobj, "predictionCol"),
     predictions = invoke(jobj, "predictions") %>% sdf_register(),
     r2 = invoke(jobj, "r2"),
     residuals = invoke(jobj, "residuals") %>% sdf_register(),
     root_mean_squared_error = invoke(jobj, "rootMeanSquaredError"),
-    t_values = try_null(invoke(jobj, "tValues")),
+    t_values = try_null(invoke(jobj, "tValues")) %>%
+      arrange_stats(),
     subclass = "ml_summary_linear_regression")
 }
 
