@@ -16,7 +16,7 @@ NULL
 #' @rdname sdf-saveload
 #' @export
 sdf_save_table <- function(x, name, overwrite = FALSE, append = FALSE) {
-  warning("sdf_save_table is deprecated, use spark_write_table instead.")
+  .Deprecated("spark_write_table")
 
   sdf <- spark_dataframe(x)
   name <- ensure_scalar_character(name)
@@ -41,7 +41,7 @@ sdf_save_table <- function(x, name, overwrite = FALSE, append = FALSE) {
 #' @rdname sdf-saveload
 #' @export
 sdf_load_table <- function(sc, name) {
-  warning("sdf_load_table is deprecated, use spark_read_table instead.")
+  .Deprecated("spark_read_table")
 
   session <- spark_session(sc)
   name <- ensure_scalar_character(name)
@@ -64,7 +64,7 @@ sdf_load_table <- function(sc, name) {
 #' @rdname sdf-saveload
 #' @export
 sdf_save_parquet <- function(x, path, overwrite = FALSE, append = FALSE) {
-  warning("sdf_save_parquet is deprecated, use spark_write_parquet instead.")
+  .Deprecated("spark_write_parquet")
 
   sdf <- spark_dataframe(x)
   path <- ensure_scalar_character(path)
@@ -79,7 +79,7 @@ sdf_save_parquet <- function(x, path, overwrite = FALSE, append = FALSE) {
 #' @rdname sdf-saveload
 #' @export
 sdf_load_parquet <- function(sc, path) {
-  warning("sdf_load_parquet is deprecated, use spark_read_parquet instead.")
+  .Deprecated("spark_read_parquet")
 
   session <- spark_session(sc)
   path <- as.character(path)
