@@ -72,7 +72,22 @@ spark_worker_apply <- function(sc) {
     # serialized groups are wrapped over single lists
     data <- group_entry[[1]]
 
-    df <- do.call(rbind.data.frame, data)
+    df <- do.call(rbind.data.frame, c(data, list(stringsAsFactors = FALSE)))
+
+    # rbind removes Date classes so we re-assign them here
+    if (length(data) > 0 && ncol(df) > 0 && nrow(df) > 0 &&
+        any(sapply(data[[1]], function(e) class(e)[[1]]) %in% c("Date", "POSIXct"))) {
+      first_row <- data[[1]]
+      for (idx in seq_along(first_row)) {
+        first_class <- class(first_row[[idx]])[[1]]
+        if (identical(first_class, "Date")) {
+          df[[idx]] <- as.Date(df[[idx]], origin = "1970-01-01")
+        } else if (identical(first_class, "POSIXct")) {
+          df[[idx]] <- as.POSIXct(df[[idx]], origin = "1970-01-01")
+        }
+      }
+    }
+
     result <- NULL
 
     if (nrow(df) == 0) {
