@@ -1,25 +1,25 @@
 package sparklyr
 
-import java.io.{DataInputStream, DataOutputStream}
-import java.io.{File, FileOutputStream, IOException}
-import java.net.{InetAddress, InetSocketAddress, ServerSocket, Socket}
-import java.util.concurrent.TimeUnit
+class BackendChannel(logger: Logger, terminate: () => Unit, serializer: Serializer, tracker: JVMObjectTracker) {
 
-import io.netty.bootstrap.ServerBootstrap
-import io.netty.channel.{ChannelFuture, ChannelInitializer, EventLoopGroup}
-import io.netty.channel.nio.NioEventLoopGroup
-import io.netty.channel.socket.SocketChannel
-import io.netty.channel.socket.nio.NioServerSocketChannel
-import io.netty.handler.codec.LengthFieldBasedFrameDecoder
-import io.netty.handler.codec.bytes.{ByteArrayDecoder, ByteArrayEncoder}
+  import java.io.{DataInputStream, DataOutputStream}
+  import java.io.{File, FileOutputStream, IOException}
+  import java.net.{InetAddress, InetSocketAddress, ServerSocket, Socket}
+  import java.util.concurrent.TimeUnit
 
-import org.apache.spark.SparkConf
-import org.apache.spark.SparkContext
-import org.apache.spark.sql.hive.HiveContext
+  import _root_.io.netty.bootstrap.ServerBootstrap
+  import _root_.io.netty.channel.{ChannelFuture, ChannelInitializer, EventLoopGroup}
+  import _root_.io.netty.channel.nio.NioEventLoopGroup
+  import _root_.io.netty.channel.socket.SocketChannel
+  import _root_.io.netty.channel.socket.nio.NioServerSocketChannel
+  import _root_.io.netty.handler.codec.LengthFieldBasedFrameDecoder
+  import _root_.io.netty.handler.codec.bytes.{ByteArrayDecoder, ByteArrayEncoder}
 
-import scala.util.Try
+  import org.apache.spark.SparkConf
+  import org.apache.spark.SparkContext
+  import org.apache.spark.sql.hive.HiveContext
 
-class BackendChannel(logger: Logger, terminate: () => Unit) {
+  import scala.util.Try
 
   private[this] var channelFuture: ChannelFuture = null
   private[this] var bootstrap: ServerBootstrap = null
@@ -45,7 +45,7 @@ class BackendChannel(logger: Logger, terminate: () => Unit) {
     val conf = new SparkConf()
     bossGroup = new NioEventLoopGroup(conf.getInt("sparklyr.backend.threads", 10))
     val workerGroup = bossGroup
-    val handler = new BackendHandler(this, logger, hostContext)
+    val handler = new BackendHandler(() => this.close(), logger, hostContext, serializer, tracker)
 
     bootstrap = new ServerBootstrap()
       .group(bossGroup, workerGroup)
