@@ -1,5 +1,26 @@
 library(sparklyr)
 
+spark_install_winutils <- function(version) {
+  hadoop_version <- if (version < "2.0.0") "2.6" else "2.7"
+  spark_dir <- paste("spark-", version, "-bin-hadoop", hadoop_version, sep = "")
+  winutils_dir <- file.path(Sys.getenv("LOCALAPPDATA"), "spark", spark_dir, "tmp", "hadoop", "bin", fsep = "\\")
+
+  if (!dir.exists(winutils_dir)) {
+    message("Installing winutils...")
+
+    dir.create(winutils_dir, recursive = TRUE)
+    winutils_path <- file.path(winutils_dir, "winutils.exe", fsep = "\\")
+
+    download.file(
+      "https://github.com/steveloughran/winutils/raw/master/hadoop-2.6.0/bin/winutils.exe",
+      winutils_path,
+      mode = "wb"
+    )
+
+    message("Installed winutils in ", winutils_path)
+  }
+}
+
 testthat_spark_connection <- function() {
   version <- Sys.getenv("SPARK_VERSION", unset = "2.2.0")
 
@@ -25,6 +46,10 @@ testthat_spark_connection <- function() {
     connected <- connection_is_open(sc)
   }
 
+  if (Sys.getenv("INSTALL_WINUTILS") == "true") {
+    spark_install_winutils(version)
+  }
+
   if (!connected) {
     config <- spark_config()
 
@@ -132,6 +157,10 @@ testthat_livy_connection <- function() {
     connected <- TRUE
   }
 
+  if (Sys.getenv("INSTALL_WINUTILS") == "true") {
+    spark_install_winutils(version)
+  }
+
   if (!connected) {
     livy_service_start(
       version = "0.5.0",
