@@ -2,6 +2,9 @@ context("livy")
 test_requires("dplyr")
 
 test_that("'spark_version()' works under Livy connections", {
+  if (.Platform$OS.type == "windows")
+    skip("Livy service unsupported in Windows")
+
   lc <- testthat_livy_connection()
 
   version <- spark_version(lc)
@@ -11,6 +14,9 @@ test_that("'spark_version()' works under Livy connections", {
 })
 
 test_that("'copy_to()' works under Livy connections", {
+  if (.Platform$OS.type == "windows")
+    skip("Livy service unsupported in Windows")
+
   lc <- testthat_livy_connection()
 
   df <- data.frame(a = c(1, 2), b = c("A", "B"), stringsAsFactors = FALSE)
@@ -20,12 +26,18 @@ test_that("'copy_to()' works under Livy connections", {
 })
 
 test_that("'livy_config()' works with extended parameters", {
+  if (.Platform$OS.type == "windows")
+    skip("Livy service unsupported in Windows")
+
   config <- livy_config(num_executors = 1)
 
   expect_equal(as.integer(config$livy.numExecutors), 1)
 })
 
 test_that("'livy_config()' works with authentication", {
+  if (.Platform$OS.type == "windows")
+    skip("Livy service unsupported in Windows")
+
   config_basic <- livy_config(username = "foo", password = "bar")
 
   expect_equal(
@@ -42,6 +54,9 @@ test_that("'livy_config()' works with authentication", {
 })
 
 test_that("'spark_apply()' works under Livy connections", {
+  if (.Platform$OS.type == "windows")
+    skip("Livy service unsupported in Windows")
+
   lc <- testthat_livy_connection()
 
   df <- data.frame(id = 10)
